@@ -56,7 +56,11 @@ Returns None if there is no next block."""
 			self.p_counter += 1
 			if self.p_counter == len(self.progressions):
 				self.p_counter = 0
-			return p
+
+			res = []
+			for x in p:
+				res.append((x[0], x[1]))
+			return res
 
 		return None
 
